<?php

namespace Drupal\message_digest\Plugin\Deriver;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Component\Utility\Unicode;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Derive message digest plugins for various intervals.
 */
class DigestDeriver extends DeriverBase {

  use StringTranslationTrait;

  /**
   * Default digest intervals.
   *
   * @var array
   */
  protected static $digestIntervals = [
    'daily' => '1 day',
    'weekly' => '1 week',
  ];

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $this->derivatives = [];
    // @todo Use simple config entities for all of these.
    foreach (static::$digestIntervals as $id => $interval) {
      $this->derivatives[$id] = [
        'id' => $id,
        'title' => Unicode::ucfirst($id),
        'description' => $this->t('Sends messages in @interval intervals.', ['@interval' => $interval]),
        'digest_interval' => $interval,
      ];
      $this->derivatives[$id] += $base_plugin_definition;
    }
    return parent::getDerivativeDefinitions($base_plugin_definition);
  }

}
